# Changelog

## [0.2.1a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/0.2.1a1) (2024-09-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.2.0...0.2.1a1)

**Merged pull requests:**

- Update oauthlib requirement from ~=3.0 to ~=3.2 in /requirements [\#66](https://github.com/OpenVoiceOS/ovos-backend-client/pull/66) ([dependabot[bot]](https://github.com/apps/dependabot))

## [V0.2.0](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.2.0) (2024-09-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/0.2.0...V0.2.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
